/*
 * Copyright (c) 2018 Nordic Semiconductor ASA
 *
 * SPDX-License-Identifier: LicenseRef-Nordic-5-Clause
 */

#ifndef BT_DEMO_SERVICE_H_
#define BT_DEMO_SERVICE_H_

/**@file
 * @defgroup bt_ds  Demo Service API
 * @{
 * @brief API for the  Demo Service (DS).
 */

#ifdef __cplusplus
extern "C" {
#endif

#include <zephyr/types.h>

#include <bluetooth/services/demo_uuids.h>

#define CONFIG_BT_DS_LOG_LEVEL LOG_LEVEL_DBG

/** @brief Callback type for when count is read. */
typedef void *(*count_cb_t)(void);

/** @brief Callback struct used by the Demo Service. */
struct bt_ds_cb {
	/** Count read callback. */
	count_cb_t count_cb;
};

/** @brief Initialize the Demo Service.
 *
 * This function registers a GATT service with two characteristics: Count
 * and Data.
 * Send notifications for the Count Characteristic to let connected peers know
 * when the count changes.
 * Read data from the Data Characteristic to get additional data.
  *
 * @param[in] callbacks Struct containing pointers to callback functions
 *			used by the service. This pointer can be NULL
 *			if no callback functions are defined.
 *
 * @retval 0 If the operation was successful.
 *           Otherwise, a (negative) error code is returned.
 */
int bt_ds_init(struct bt_ds_cb *callbacks);

#ifdef __cplusplus
}
#endif

/**
 * @}
 */

#endif /* BT_DEMO_SERVICE_H_ */
